@@ -1,12 +1,17 @@
 import os.path
+import tempfile
+import shutil
+from subprocess import Popen
 
 from .base import CodeTemplate, KeyValueId, Action, GeneratedItem, owner, NSApp, const
 from .view import Pack
 from .menu import Menu, MainMenu
 from .window import Window
-from .button import Button
+from .button import Button, Checkbox
 from .label import Label
 from .textfield import TextField
+from .popup import Popup
+from .combo import Combobox
 from .font import Font, FontFamily, FontSize, FontTrait
 
 try:
@@ -27,7 +32,10 @@ return result;
 }
 """
 
-def generate(module_path, dest):
+# ownerless is used by runUI. When running a UI, we take one UI script out of its context, so
+# any owner assignment will make code compilation fail. Since we just want to preview the UI, we
+# don't need those assignments, so we skip them.
+def generate(modulePath, dest, ownerless=False):
     module_globals = {
         'owner': owner,
         'NSApp': NSApp,
@@ -37,8 +45,11 @@ def generate(module_path, dest):
         'Action': Action,
         'Window': Window,
         'Button': Button,
+        'Checkbox': Checkbox,
         'Label': Label,
         'TextField': TextField,
+        'Popup': Popup,
+        'Combobox': Combobox,
         'Font': Font,
         'FontFamily': FontFamily,
         'FontSize': FontSize,
@@ -46,9 +57,15 @@ def generate(module_path, dest):
         'Pack': Pack,
     }
     module_locals = {}
-    execfile(module_path, module_globals, module_locals)
+    execfile(modulePath, module_globals, module_locals)
     assert 'result' in module_locals
     tmpl = CodeTemplate(UNIT_TMPL)
+    if ownerless:
+        owner._clear()
+        owner._name = 'nil'
+        tmpl.ownerclass = 'id'
+    else:
+        tmpl.ownerclass = module_locals.get('ownerclass', 'id')
     tmpl.name = os.path.splitext(os.path.basename(dest))[0]
     toGenerate = []
     for key, value in module_locals.items():
@@ -63,9 +80,20 @@ def generate(module_path, dest):
             continue
         codePieces.append(item.generate())
     result = module_locals['result']
-    tmpl.ownerclass = module_locals.get('ownerclass', 'id')
     tmpl.classname = result.OBJC_CLASS
     tmpl.contents = '\n'.join(codePieces)
     fp = open(dest, 'wt')
     fp.write(tmpl.render())
     fp.close()
+
+def runUI(modulePath):
+    runtemplatePath = os.path.join(os.path.dirname(os.path.abspath(__file__)), 'runtemplate')
+    assert os.path.exists(runtemplatePath)
+    tmpPath = tempfile.mkdtemp()
+    destPath = os.path.join(tmpPath, 'runtemplate')
+    shutil.copytree(runtemplatePath, destPath)
+    shutil.copy(modulePath, os.path.join(destPath, 'MainWindow.py'))
+    cmd = 'cd "%s" && python ./waf configure && python ./waf && open build/RunUI.app -W && cd ../.. && rm -r "%s"' % (destPath, tmpPath)
+    p = Popen(cmd, shell=True)
+    p.wait()
+
